/*
 *  SokoBan, a Sokoban game.
 *  Copyright (C) 2008  Colomban Wendling <ban@herbesfolles.org>
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include <SDL/SDL.h>
#include <SDL/SDL_image.h>

#include "sokoban.h"
#include "object.h"
#include "map.h"
#include "i18n.h"
#include "gallery.h"


static Object *_wall = NULL;
static Object *_ground = NULL;
static Object *_box = NULL;
static Object *_boxdone = NULL;
static Object *_point = NULL;
static Object *_none = NULL;


/*static SDL_Surface* _gallery_loadImageFromFile (const char* file)
{
   trace ();
   printf ("  Trying to open '%s'...\n", file);
   
   SDL_Surface *surface;
   
   printf ("==\n");
   surface = IMG_Load (file);
   printf ("==\n");
   
   if (!surface)
   {
      fprintf (stderr, "** Failed to load image from file '%s': %s\n",
               file, SDL_GetError ());
   }
   
   return surface;
}*/
#define _gallery_loadImageFromFile(x) IMG_Load(x)


Object* gallery_getItem (Map itemId)
{
   trace ();
   
   switch (itemId)
   {
      case WALL:     return _wall; break;
      case GROUND:   return _ground; break;
      case BOX:      return _box; break;
      case BOXDONE:  return _boxdone; break;
      case POINT:    return _point; break;
      default:       return _none; break;
   }
}


MyBool gallery_init (void)
{
   trace ();
   
   SDL_ClearError (); // clear possible previous uncleared error
   
   _none = object_newWithData (
                  _gallery_loadImageFromFile (DATADIR"images/none.png"), 0, 0);
   _wall = object_newWithData (
                  _gallery_loadImageFromFile (DATADIR"images/wall.png"), 0, 0);
   _ground = object_newWithData (
                _gallery_loadImageFromFile (DATADIR"images/ground.png"), 0, 0);
   _box = object_newWithData (
                   _gallery_loadImageFromFile (DATADIR"images/box.png"), 0, 0);
   _boxdone = object_newWithData (
               _gallery_loadImageFromFile (DATADIR"images/boxdone.png"), 0, 0);
   _point = object_newWithData (
                 _gallery_loadImageFromFile (DATADIR"images/point.png"), 0, 0);
   
   if (SDL_GetError ()[0] != '\0') // hack to check if an error was reported
   {
      fprintf (stderr, _("** Gallery init failed\n"));
      
      gallery_exit ();
      return FALSE;
   }
   
   return TRUE;
}

void gallery_exit (void)
{
   trace ();
   
   object_free (_wall);
   object_free (_ground);
   object_free (_box);
   object_free (_boxdone);
   object_free (_point);
   object_free (_none);
}
