/*
 *  SokoBan, a Sokoban game.
 *  Copyright (C) 2008  Colomban Wendling <ban@herbesfolles.org>
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef __PLAYER_H__
#define __PLAYER_H__


#include <SDL/SDL.h>


typedef enum _PlayerDirection PlayerDirection;
enum _PlayerDirection
{
   DOWN,
   UP,
   LEFT,
   RIGHT
};


typedef struct _Player Player;
struct _Player
{
   /* order is important for surface & pos to be Object-compatible */
   SDL_Surface *surface; /**< pointer to the current image (one of up, dow,
                                                              left or right) */
   SDL_Rect pos; /**< position of the player */
   
   SDL_Surface *up;      /**< image of the player moving up */
   SDL_Surface *down;    /**< image of the player moving down */
   SDL_Surface *left;    /**< image of the player moving left */
   SDL_Surface *right;   /**< image of the player moving down */
};


#define player_setPos(x,y) (player_setPosX (x), player_setPosY (y))

int player_getMoves (void);
int player_getBoxMoves (void);
void player_resetMoves (void);
void player_addMove (void);
void player_addBoxMove (void);


Player* player_get (void);

int player_getPosX (void);
int player_getPosY (void);
void player_setPosX (int x);
void player_setPosY (int y);

Player* player_init (void);
void player_free (void);

void player_setDirection (PlayerDirection dir);
void player_move (PlayerDirection direction);


#endif /* guard */
